==> nextcloud-17.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/ca.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "L'operador donat no és vàlid",
    "The given regular expression is invalid" : "L'expressió regular donada no és vàlida",
    "The given file size is invalid" : "La mida de fitxer donat no és vàlid",
    "The given tag id is invalid" : "L'Id d'etiqueta donat no és vàlid",
    "The given IP range is invalid" : "El rang d'IPs donat no és vàlid",
    "The given IP range is not valid for IPv4" : "El rang d'IP donat no és vàlid per IPv4",
    "The given IP range is not valid for IPv6" : "El rang d'IP donat no és vàlid per IPv6",
    "The given time span is invalid" : "El rang de temps donat no és vàlid",
    "The given start time is invalid" : "El temps d'inici donat no és vàlid",
    "The given end time is invalid" : "El temps de finalització donat no és vàlid",
    "The given group does not exist" : "El grup donat no existeix",
    "File" : "Fitxer",
    "File created" : "Fitxer creat",
    "File updated" : "Fitxer actualitzat",
    "File renamed" : "Fitxer reanomenat",
    "File deleted" : "Fitxer suprimit",
    "File accessed" : "Fitxer accedit",
    "File copied" : "Fitxer copiat",
    "Tag assigned" : "Etiqueta assignada",
    "Operation #%s does not exist" : "L'operació #%s no existeix",
    "Entity %s does not exist" : "L'entitat %s no existeix.",
    "Entity %s is invalid" : "L'entitat %s no és vàlida.",
    "No events are chosen." : "No s'ha triat cap esdeveniment.",
    "Entity %s has no event %s" : "L'entitat %s no té cap esdeveniment %s",
    "Operation %s does not exist" : "L'operació %s no existeix",
    "Operation %s is invalid" : "L'operació %s no és vàlida",
    "Check %s does not exist" : "Comprovació %s no existeix",
    "Check %s is invalid" : "Comprovació %s no és vàlid",
    "Check %s is not allowed with this entity" : "La comprovació de %s no es permet amb aquesta entitat.",
    "Check #%s does not exist" : "Comprovació #%s no existeix",
    "Check %s is invalid or does not exist" : "Comprovació %s no és vàlida o no existeix",
    "Nextcloud workflow engine" : "Motor de flux de treball de Nextcloud",
    "Select a filter" : "Seleccioneu un filtre",
    "Select a comparator" : "Seleccioneu un comparador",
    "Select a file type" : "Seleccioneu un tipus de fitxer",
    "Images" : "Imatges",
    "Office documents" : "Documents d'oficina",
    "PDF documents" : "Documents PDF",
    "Custom mimetype" : "Tipus mime personalitzat",
    "No results" : "No hi ha resultats",
    "%s (invisible)" : "%s (invisible)",
    "%s (restricted)" : "%s (restringit)",
    "Select a request URL" : "Seleccioneu un URL de petició",
    "Predefined URLs" : "URLs predefinits",
    "Files WebDAV" : "Fitxers WebDAV",
    "Others" : "Altres",
    "Custom URL" : "URL personalitzat",
    "Select a user agent" : "Seleccioneu un agent d'usuari",
    "Android client" : "Client android",
    "iOS client" : "Client iOS",
    "Desktop client" : "Client d'escriptori",
    "Thunderbird & Outlook addons" : "Complements de Thunderbird i Outlook",
    "Custom user agent" : "Agent d'usuari personalitzat",
    "When" : "Quan",
    "and" : "i",
    "The configuration is invalid" : "La configuració no és vàlida.",
    "Save" : "Desa",
    "Show less" : "Mostra'n menys",
    "Show more" : "Mostra'n més",
    "File name" : "Nom del fitxer",
    "is" : "és",
    "is not" : "no és",
    "matches" : "coincidències",
    "does not match" : "No hi ha coincidències",
    "File MIME type" : "Tipus MIME del fitxer",
    "File size (upload)" : "Mida del fitxer (carrega)",
    "less" : "menys",
    "less or equals" : "menor o igual",
    "greater or equals" : "major o igual",
    "greater" : "superior",
    "Request remote address" : "Demana adreça remota",
    "matches IPv4" : "coincideix amb IPv4",
    "does not match IPv4" : "No coincideix amb IPv4",
    "matches IPv6" : "Coincideix amb IPv6",
    "does not match IPv6" : "No coincideix amb IPv6",
    "File system tag" : "Etiqueta del sistema de fitxers",
    "is tagged with" : "està estiquetat amb",
    "is not tagged with" : "no està etiquetat amb",
    "Request URL" : "URL de sol·licitud",
    "Request time" : "Temps d'espera",
    "between" : "entre",
    "not between" : "no entre",
    "Request user agent" : "Sol·licita agent d'usuari",
    "User group membership" : "Pertinença a grup d'usuaris",
    "is member of" : "és membre de",
    "is not member of" : "no és membre de",
    "Short rule description" : "Descripció breu de la regla",
    "Add rule" : "Afegeix regla",
    "Reset" : "Neteja",
    "Saving…" : "S'està desant...",
    "Group list is empty" : "La llista del grup és buida",
    "Unable to retrieve the group list" : "No es pot obtenir la llista del grup",
    "Saved" : "S'ha desat",
    "Saving failed:" : "S'ha produït un error en desar:",
    "Add rule group" : "Afegeix una regla de grup",
    "Example: {placeholder}" : "Exemple: {placeholder}",
    "Select tag…" : "Selecciona etiqueta...",
    "Start" : "Comença",
    "End" : "Finalitza",
    "Select timezone…" : "Selecciona fus horari",
    "Sync clients" : "Sincronitza les aplicacions clients",
    "Workflow" : "Flux de treball",
    "Files workflow engine" : "Fitxers del motor de flux de treball",
    "Open documentation" : "Obre la documentació",
    "Loading…" : "S'està carregant...",
    "Tag management" : "Gestió d'etiquetes"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/ca.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "L'operador donat no és vàlid",
    "The given regular expression is invalid" : "L'expressió regular donada no és vàlida",
    "The given file size is invalid" : "La mida de fitxer donat no és vàlid",
    "The given tag id is invalid" : "L'Id d'etiqueta donat no és vàlid",
    "The given IP range is invalid" : "El rang d'IPs donat no és vàlid",
    "The given IP range is not valid for IPv4" : "El rang d'IP donat no és vàlid per IPv4",
    "The given IP range is not valid for IPv6" : "El rang d'IP donat no és vàlid per IPv6",
    "The given time span is invalid" : "El rang de temps donat no és vàlid",
    "The given start time is invalid" : "El temps d'inici donat no és vàlid",
    "The given end time is invalid" : "El temps de finalització donat no és vàlid",
    "The given group does not exist" : "El grup donat no existeix",
    "File" : "Fitxer",
    "File created" : "Fitxer creat",
    "File updated" : "Fitxer actualitzat",
    "File renamed" : "Fitxer reanomenat",
    "File deleted" : "Fitxer suprimit",
    "File accessed" : "Fitxer accedit",
    "File copied" : "Fitxer copiat",
    "Tag assigned" : "Etiqueta assignada",
    "Operation #%s does not exist" : "L'operació #%s no existeix",
    "Entity %s does not exist" : "L'entitat %s no existeix.",
    "Entity %s is invalid" : "L'entitat %s no és vàlida.",
    "No events are chosen." : "No s'ha triat cap esdeveniment.",
    "Entity %s has no event %s" : "L'entitat %s no té cap esdeveniment %s",
    "Operation %s does not exist" : "L'operació %s no existeix",
    "Operation %s is invalid" : "L'operació %s no és vàlida",
    "Check %s does not exist" : "Comprovació %s no existeix",
    "Check %s is invalid" : "Comprovació %s no és vàlid",
    "Check %s is not allowed with this entity" : "La comprovació de %s no es permet amb aquesta entitat.",
    "Check #%s does not exist" : "Comprovació #%s no existeix",
    "Check %s is invalid or does not exist" : "Comprovació %s no és vàlida o no existeix",
    "Nextcloud workflow engine" : "Motor de flux de treball de Nextcloud",
    "Select a filter" : "Seleccioneu un filtre",
    "Select a comparator" : "Seleccioneu un comparador",
    "Select a file type" : "Seleccioneu un tipus de fitxer",
    "Images" : "Imatges",
    "Office documents" : "Documents d'oficina",
    "PDF documents" : "Documents PDF",
    "Custom mimetype" : "Tipus mime personalitzat",
    "No results" : "No hi ha resultats",
    "%s (invisible)" : "%s (invisible)",
    "%s (restricted)" : "%s (restringit)",
    "Select a request URL" : "Seleccioneu un URL de petició",
    "Predefined URLs" : "URLs predefinits",
    "Files WebDAV" : "Fitxers WebDAV",
    "Others" : "Altres",
    "Custom URL" : "URL personalitzat",
    "Select a user agent" : "Seleccioneu un agent d'usuari",
    "Android client" : "Client android",
    "iOS client" : "Client iOS",
    "Desktop client" : "Client d'escriptori",
    "Thunderbird & Outlook addons" : "Complements de Thunderbird i Outlook",
    "Custom user agent" : "Agent d'usuari personalitzat",
    "When" : "Quan",
    "and" : "i",
    "Cancel" : "Cancel·la",
    "Delete" : "Eliminar",
    "The configuration is invalid" : "La configuració no és vàlida.",
    "Active" : "Actiu",
    "Save" : "Desa",
    "Browse the app store" : "Navegueu per la botiga d’aplicacions",
    "Show less" : "Mostra'n menys",
    "Show more" : "Mostra'n més",
    "matches" : "coincidències",
    "does not match" : "No hi ha coincidències",
    "is" : "és",
    "is not" : "no és",
    "File name" : "Nom del fitxer",
    "File MIME type" : "Tipus MIME del fitxer",
    "File size (upload)" : "Mida del fitxer (carrega)",
    "less" : "menys",
    "less or equals" : "menor o igual",
    "greater or equals" : "major o igual",
    "greater" : "superior",
    "Request remote address" : "Demana adreça remota",
    "matches IPv4" : "coincideix amb IPv4",
    "does not match IPv4" : "No coincideix amb IPv4",
    "matches IPv6" : "Coincideix amb IPv6",
    "does not match IPv6" : "No coincideix amb IPv6",
    "File system tag" : "Etiqueta del sistema de fitxers",
    "is tagged with" : "està estiquetat amb",
    "is not tagged with" : "no està etiquetat amb",
    "Request URL" : "URL de sol·licitud",
    "Request time" : "Temps d'espera",
    "between" : "entre",
    "not between" : "no entre",
    "Request user agent" : "Sol·licita agent d'usuari",
    "User group membership" : "Pertinença a grup d'usuaris",
    "is member of" : "és membre de",
    "is not member of" : "no és membre de",
    "Short rule description" : "Descripció breu de la regla",
    "Add rule" : "Afegeix regla",
    "Reset" : "Neteja",
    "Saving…" : "S'està desant...",
    "Group list is empty" : "La llista del grup és buida",
    "Unable to retrieve the group list" : "No es pot obtenir la llista del grup",
    "Saved" : "S'ha desat",
    "Saving failed:" : "S'ha produït un error en desar:",
    "Add rule group" : "Afegeix una regla de grup",
    "Example: {placeholder}" : "Exemple: {placeholder}",
    "Select tag…" : "Selecciona etiqueta...",
    "Start" : "Comença",
    "End" : "Finalitza",
    "Select timezone…" : "Selecciona fus horari",
    "Sync clients" : "Sincronitza les aplicacions clients",
    "Workflow" : "Flux de treball",
    "Files workflow engine" : "Fitxers del motor de flux de treball",
    "Open documentation" : "Obre la documentació",
    "Loading…" : "S'està carregant...",
    "Tag management" : "Gestió d'etiquetes"
},
"nplurals=2; plural=(n != 1);");
